Skip to contents

Tools to compute and map biodiversity turnover at the macroscale. 'dissmapr' provides a reproducible, end-to-end workflow for computing and mapping compositional dissimilarity and biodiversity turnover across large spatial scales, including occurrence-data retrieval, environmental-data extraction, flexible grid generation, order-wise dissimilarity computation (zeta diversity and multi-site generalised dissimilarity modelling) and bioregional mapping.

Author

Maintainer: Sandra MacFadyen macfadyen@sun.ac.za (ORCID)

Authors:

Other contributors:

  • Stellenbosch University [copyright holder]

  • European Union (Horizon Europe grant agreement ID 101059592 (B-Cubed)) [funder]